#!/bin/bash
echo "Bash version ${BASH_VERSION}..."
for J in 0.0 0.05 0.10 0.15 0.20 0.25 0.30
  do
  echo "Creating directory for J=$J eV"
  for U in 0.5 1.0 1.5 2.0 2.5 3.0 3.5 4.0 4.5 5.0 5.5 6.0 6.5 7.0 
    do 
    echo "Creating directory for U=$U eV"
    mkdir -p "./J$J/U$U/"
    cp ./m1.h5  "./J$J/U$U/m1.h5"
    cd "./J$J/U$U/" 
    cat > "./sjob.sh" << EOFF
#!/bin/bash
#SBATCH --job-name="close_J${J}_U${U}"
#SBATCH --time=24:00:00
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=128
#SBATCH --account=eth3
#SBATCH --ntasks-per-core=1
#SBATCH --constraint=mc
#SBATCH --partition=normal
#SBATCH --output=std_%j.out
#SBATCH --error=std_%j.err

module load sarus

re="^b([0-9]{1,3})-U([0-9]\.[0-9])-J([0-9]\.[0-9]{1,2})_?([a-zA-Z]+)?"
[[ \$SLURM_JOB_NAME =~ \$re ]] && bval="\${BASH_REMATCH[1]}" && uval="\${BASH_REMATCH[2]}" && jval="\${BASH_REMATCH[3]}" && flag="\${BASH_REMATCH[4]}"

workdir="\$SLURM_SUBMIT_DIR/out"

echo "WORKDIR: \$workdir"

cat > dmft_config.ini << EOF
[general]
seedname = m1
jobname = \${SLURM_JOB_NAME}
csc = False

#dft_mu = 0.
solver_type = cthyb
n_l = 31

n_w = 501
eta = 0.05
n_iw = 1001
w_range = -10,10

n_iter_dmft = 30

block_threshold = 1e-03

h_int_type = kanamori
h_int_basis = wannier90
U = $U
J = $J
beta = 40

calc_mu_method = brent
prec_mu = 0.001

sigma_mix = 1.0
dc_type = 1
dc = True
dc_dmft = True
calc_energies = True

h5_save_freq = 1

[solver]
length_cycle = 120
n_warmup_cycles = 10000
n_cycles_tot = 4.0e+8
imag_threshold = 1e-5
measure_G_l = True
measure_G_tau = False
legendre_fit = False
measure_density_matrix = True

[dft]
dft_code = qe
n_cores = 36
mpi_env = local
projector_type = w90
dft_exec = pw.x
w90_exec = wannier90.x
EOF

export PYTHONPATH=/users/pmlkvik/solid_dmft-unstable/build/python:$PYTHONPATH

echo $PYTHONPATH

echo "*** Starting solid_dmft on `date` ***"
sarus run --mount=type=bind,source=/users/pmlkvik,destination=/users/pmlkvik --mount=type=bind,source=$SCRATCH,destination=$SCRATCH --workdir=$PWD load/library/triqs_openmpi:unstable_rebuild mpirun -n 128 python3 /users/pmlkvik/solid_dmft-unstable/build/bin/solid_dmft
echo "*** Job ended on `date` ***"
EOFF
    echo "I am in folder:"
    pwd
    echo "Running the DMFT cycle for parameters: U=$U eV, J=$J eV"
    sbatch ./sjob.sh
    cd ../..
  done
done


