#!/bin/bash
#SBATCH --job-name="dist_test"
#SBATCH --time=1:00:00
#SBATCH --nodes=1
#SBATCH --ntasks-per-node=128
#SBATCH --account=eth3
#SBATCH --ntasks-per-core=1
#SBATCH --constraint=mc
#SBATCH --partition=normal
#SBATCH --output=std_%j.out
#SBATCH --error=std_%j.err

seedname="m1"
uval=2.00
jval=0.10
bval=40

workdir="$SLURM_SUBMIT_DIR/$SLURM_JOB_NAME"
echo "WORKDIR: $workdir"

cat > dmft_config.ini << EOF

[general]
seedname = ${seedname}
jobname = out
csc = True

solver_type = cthyb
n_w = 1001
w_range = -10,10
eta = 0.05
n_iw = 1001
beta = ${bval}
n_l = 31

calc_mu_method = brent
prec_mu = 0.001

h_int_type = kanamori
h_int_basis = wannier90 
U = ${uval}
J = ${jval}

h5_save_freq = 1

n_iter_dmft_first = 30
n_iter_dmft_per = 1
n_iter_dmft = 100
sigma_mix = 0.5

dc_type = 1
dc = True
dc_dmft = True
calc_energies = True

[solver]
length_cycle = 120
n_warmup_cycles = 10000
n_cycles_tot = 4.0e+8
imag_threshold = 1e-5
measure_G_l = True
measure_density_matrix = True

[dft]
dft_code = qe
n_cores = 128
projector_type = w90
dft_exec = pw.x
w90_exec = wannier90.x
w90_tolerance = 10
EOF

cp -r ../save/* .
rm ${seedname}.h5

echo "*** Starting solid_dmft on `date` ***"
sarus run --mount=type=bind,source=/users/pmlkvik,destination=/users/pmlkvik --mount=type=bind,source=$SCRATCH,destination=$SCRATCH --workdir=$PWD load/library/triqs_openmpi:unstable_rebuild mpirun -n 128 python3 /users/pmlkvik/solid_dmft-unstable/build/bin/solid_dmft
echo "*** Job ended on `date` ***"

